================
Starship Takeoff
================

You are a starship captain. You have crashed your ship on a strange planet and must take off again quickly in the alien ship you have captured. The ship's computer tells you the gravity on the planet. You must guess the force required for a successful take off. If you guess too low, the ship will not lift off the ground. If you guess too high, the ship's fail-safe mechanism comes into operation to prevent it from being burnt up. If you are still on the planet after ten tries, the aliens will capture you.

The code
========

.. literalinclude:: starship_takeoff.py
   :language: python


How to make the game harder
---------------------------

You can change to the program to give you less than 10 goes. Do this by altering the number on lines 24 and 42 (They must be the same).

Puzzle corner
-------------

You could change the range of possible forces. See if you can work out how.


